|BMicro|
========

|PyPI Version| |Build Status Unix| |Coverage Status| |Docs Status|


This is a Python library for the post-measurement analysis of
Brillouin microscopy data.


Documentation
-------------
The documentation, including the code reference and examples, is available at
`bmicro.readthedocs.io <https://bmicro.readthedocs.io/en/stable/>`__.


Installation
------------

::

    pip install bmicro

For more options, please check out the `documentation
<https://bmicro.readthedocs.io/en/latest/sec_getting_started.html#installation>`__.


Contributing
------------
Please read our `information for developers
<https://bmicro.readthedocs.io/en/latest/sec_develop.html>`__.


.. |BMicro| image:: https://raw.github.com/BrillouinMicroscopy/BMicro/main/docs/logo/bmicro.png
.. |PyPI Version| image:: https://img.shields.io/pypi/v/bmicro.svg
   :target: https://pypi.python.org/pypi/bmicro
.. |Build Status Unix| image:: https://img.shields.io/github/actions/workflow/status/BrillouinMicroscopy/bmicro/check_stable_pypi.yml
   :target: https://github.com/BrillouinMicroscopy/BMicro/actions?query=workflow%3AChecks
.. |Coverage Status| image:: https://img.shields.io/codecov/c/github/BrillouinMicroscopy/BMicro/main.svg
   :target: https://codecov.io/gh/BrillouinMicroscopy/BMicro
.. |Docs Status| image:: https://readthedocs.org/projects/bmicro/badge/?version=latest
   :target: https://readthedocs.org/projects/bmicro/builds/
   
   
How to cite
-----------

If you use BMicro in a scientific publication, please cite it with:

> Raimund Schlüßler and others (2023), BMicro version X.X.X: Python program for the evaluation of Brillouin microscopy data sets [Software]. Available at https://github.com/BrillouinMicroscopy/BMicro.
